@@ -5,6 +5,7 @@ from pydantic import create_model, BaseModel, Field
 
 from .api_wrapper import ZephyrEssentialApiWrapper
 from ..base.tool import BaseAction
+from ..elitea_base import filter_missconfigured_index_tools
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length
 from ...configurations.pgvector import PgVectorConfiguration
 from ...configurations.zephyr_essential import ZephyrEssentialConfiguration
@@ -51,6 +52,7 @@ class ZephyrEssentialToolkit(BaseToolkit):
         )
 
     @classmethod
+    @filter_missconfigured_index_tools
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
